@@ -133,6 +133,9 @@ def _get_learner_type(jl_obj):
     elif (not _iai_version_less_than("2.1.0") and
           _Main.isa(jl_obj, _IAI.XGBoostRegressor)):
         L = XGBoostRegressor
+    elif (not _iai_version_less_than("2.3.0") and
+          _Main.isa(jl_obj, _IAI.GLMNetCVClassifier)):
+        L = GLMNetCVClassifier
     elif (not _iai_version_less_than("2.1.0") and
           _Main.isa(jl_obj, _IAI.GLMNetCVRegressor)):
         L = GLMNetCVRegressor
