@@ -10,7 +10,7 @@ def split_data(*args, **kwargs):
     `(X_train, y_train), (X_test, y_test)`, for a problem of type `task`.
 
     Julia Equivalent:
-    `IAI.split_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.split_data>`
+    `IAI.split_data <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.split_data>`
 
     Examples
     --------
@@ -23,7 +23,7 @@ def set_rich_output_param(*args, **kwargs):
     """Sets the global rich output parameter `key` to `value`.
 
     Julia Equivalent:
-    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.set_rich_output_param!>`
+    `IAI.set_rich_output_param! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.set_rich_output_param!>`
 
     Examples
     --------
@@ -36,7 +36,7 @@ def get_rich_output_params(*args, **kwargs):
     """Return the current global rich output parameter settings.
 
     Julia Equivalent:
-    `IAI.get_rich_output_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_rich_output_params>`
+    `IAI.get_rich_output_params <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_rich_output_params>`
 
     Examples
     --------
@@ -49,7 +49,7 @@ def delete_rich_output_param(*args, **kwargs):
     """Delete the global rich output parameter `key`.
 
     Julia Equivalent:
-    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
+    `IAI.delete_rich_output_param! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.delete_rich_output_param!>`
 
     Examples
     --------
@@ -62,7 +62,7 @@ def read_json(filename):
     """Read in a learner or grid saved in JSON format from `filename`.
 
     Julia Equivalent:
-    `IAI.read_json <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.read_json>`
+    `IAI.read_json <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.read_json>`
 
     Examples
     --------
@@ -108,7 +108,7 @@ class Learner():
         """Fit a model using the parameters in learner and the data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.fit! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit!>`
+        `IAI.fit! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.fit!>`
 
         Examples
         --------
@@ -117,7 +117,7 @@ class Learner():
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_convert(self._jl_obj, *args, **kwargs)
@@ -127,7 +127,7 @@ class Learner():
         """Write learner or grid to `filename` in JSON format.
 
         Julia Equivalent:
-        `IAI.write_json <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.write_json>`
+        `IAI.write_json <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.write_json>`
 
         Examples
         --------
@@ -142,7 +142,7 @@ class Learner():
         """Return the value of all learner parameters.
 
         Julia Equivalent:
-        `IAI.get_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_params>`
+        `IAI.get_params <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_params>`
 
         Examples
         --------
@@ -157,7 +157,7 @@ class Learner():
         """Set all supplied parameters on learner.
 
         Julia Equivalent:
-        `IAI.set_params! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.set_params!>`
+        `IAI.set_params! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.set_params!>`
 
         Examples
         --------
@@ -173,7 +173,7 @@ class Learner():
         """Return an unfitted copy of the learner with the same parameters.
 
         Julia Equivalent:
-        `IAI.clone <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.clone>`
+        `IAI.clone <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.clone>`
 
         Examples
         --------
@@ -197,7 +197,7 @@ class SupervisedLearner(Learner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict>`
+        `IAI.predict <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict>`
 
         Examples
         --------
@@ -209,7 +209,7 @@ class SupervisedLearner(Learner):
         """Calculates the score for the learner on data `X` and `y`.
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.score>`
+        `IAI.score <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.score>`
 
         Examples
         --------
@@ -223,7 +223,7 @@ class SupervisedLearner(Learner):
         they sum to one.
 
         Julia Equivalent:
-        `IAI.variable_importance <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.variable_importance>`
+        `IAI.variable_importance <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.variable_importance>`
 
         Examples
         --------
@@ -231,6 +231,23 @@ class SupervisedLearner(Learner):
         """
         return _IAI.variable_importance_convert(self._jl_obj)
 
+    def get_features_used(self):
+        """Return a list of feature names used by the learner.
+
+        Julia Equivalent:
+        `IAI.get_features_used <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_features_used>`
+
+        Examples
+        --------
+        >>> lnr.get_features_used()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "get_features_used")
+        return _IAI.get_features_used_convert(self._jl_obj)
+
 
 class UnsupervisedLearner(Learner):
     """Abstract type encompassing all learners for unsupervised tasks"""
@@ -245,7 +262,7 @@ class ClassificationLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_proba <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_proba>`
+        `IAI.predict_proba <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_proba>`
 
         Examples
         --------
@@ -263,15 +280,18 @@ class SurvivalLearner(SupervisedLearner):
     """Abstract type encompassing all learners for survival tasks"""
 
     def predict(self, *args, **kwargs):
-        jl_curves = _IAI.predict_convert(self._jl_obj, *args, **kwargs)
-        return [SurvivalCurve(jl_curve) for jl_curve in jl_curves]
+        out = _IAI.predict_convert(self._jl_obj, *args, **kwargs)
+        if len(out) > 0 and out[0].__class__.__name__ == 'jlwrap':
+            return [SurvivalCurve(jl_curve) for jl_curve in out]
+        else:
+            return _np.array(out)
 
     def predict_expected_survival_time(self, *args, **kwargs):
         """Return the expected survival time estimate made by the learner for
         each point in the data `X`.
 
         Julia Equivalent:
-        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
 
         Examples
         --------
@@ -293,7 +313,7 @@ class SurvivalLearner(SupervisedLearner):
         survival time.
 
         Julia Equivalent:
-        `IAI.predict_hazard <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_hazard>`
+        `IAI.predict_hazard <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_hazard>`
 
         Examples
         --------
@@ -315,7 +335,7 @@ class PrescriptionLearner(SupervisedLearner):
         learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_outcomes-Tuple%7BLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D>`
 
         Examples
         --------
@@ -332,7 +352,7 @@ class PolicyLearner(SupervisedLearner):
         under the prescriptions made by the learner.
 
         Julia Equivalent:
-        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
+        `IAI.predict_outcomes <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_outcomes-Union%7BTuple%7BO%7D%2C%2520Tuple%7BLearner%7BIAIBase.PolicyTask%7BO%7D%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s60%22%2C2%7D%2520where%2520var%22%23s60%22%3C%3AReal%7D%7D%7D%2520where%2520O>`
 
         Examples
         --------
@@ -350,7 +370,7 @@ class PolicyLearner(SupervisedLearner):
         point in the features `X` as predicted by the learner.
 
         Julia Equivalent:
-        `IAI.predict_treatment_rank <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_treatment_rank>`
+        `IAI.predict_treatment_rank <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_treatment_rank>`
 
         Examples
         --------
@@ -369,7 +389,7 @@ class PolicyLearner(SupervisedLearner):
         of the learner for each point in the features `X`.
 
         Julia Equivalent:
-        `IAI.predict_treatment_outcome <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.predict_treatment_outcome>`
+        `IAI.predict_treatment_outcome <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.predict_treatment_outcome>`
 
         Examples
         --------
@@ -388,7 +408,7 @@ class GridSearch(Learner):
     """Controls grid search over parameter combinations in `params` for `lnr`.
 
     Julia Equivalent:
-    `IAI.GridSearch <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.GridSearch>`
+    `IAI.GridSearch <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.GridSearch>`
 
     Examples
     --------
@@ -469,7 +489,7 @@ class GridSearch(Learner):
         the grid.
 
         Julia Equivalent:
-        `IAI.get_learner <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_learner>`
+        `IAI.get_learner <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_learner>`
 
         Examples
         --------
@@ -484,7 +504,7 @@ class GridSearch(Learner):
         """Return the best parameter combination from the grid.
 
         Julia Equivalent:
-        `IAI.get_best_params <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_best_params>`
+        `IAI.get_best_params <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_best_params>`
 
         Examples
         --------
@@ -507,7 +527,7 @@ class GridSearch(Learner):
         """Return a summary of the results from the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_result_summary <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_result_summary>`
+        `IAI.get_grid_result_summary <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_grid_result_summary>`
 
         Examples
         --------
@@ -522,7 +542,7 @@ class GridSearch(Learner):
         """Return a `list` of `dict`s detailing the results of the grid search.
 
         Julia Equivalent:
-        `IAI.get_grid_result_details <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_grid_result_details>`
+        `IAI.get_grid_result_details <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_grid_result_details>`
 
         Examples
         --------
@@ -549,7 +569,7 @@ class GridSearch(Learner):
         """Fit a grid with data `X` and `y` using k-fold cross-validation.
 
         Julia Equivalent:
-        `IAI.fit_cv! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit_cv!>`
+        `IAI.fit_cv! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.fit_cv!>`
 
         Examples
         --------
@@ -558,7 +578,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         _IAI.fit_cv_convert(self._jl_obj, *args, **kwargs)
@@ -569,7 +589,7 @@ class GridSearch(Learner):
         cross-validation and impute missing values in `X`.
 
         Julia Equivalent:
-        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.fit_transform_cv!>`
+        `IAI.fit_transform_cv! <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.fit_transform_cv!>`
 
         Examples
         --------
@@ -578,7 +598,7 @@ class GridSearch(Learner):
         Parameters
         ----------
         Refer to the documentation on
-        `data preparation <https://docs.interpretable.ai/v2.1.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
+        `data preparation <https://docs.interpretable.ai/v2.2.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
         self._check_delegate("fit_transform", "fit_transform_cv")
@@ -627,7 +647,7 @@ class GridSearch(Learner):
         """Plot the grid search results for Optimal Feature Selection learners.
 
         Returns a
-        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.figure.Figure.html#matplotlib.figure.Figure>`
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/figure_api.html?highlight=figure#matplotlib.figure.Figure>`
         containing the plotted results.
 
         In a Jupyter Notebook, the plot will be shown automatically. In a
@@ -642,7 +662,7 @@ class GridSearch(Learner):
         type : str
             The type of plot to construct, either `"validation"` or
             `"importance"`. For more information refer to the
-            `Julia documentation for plotting grid search results <https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/visualization/#Plotting-Grid-Search-Results-1>`.
+            `Julia documentation for plotting grid search results <https://docs.interpretable.ai/v2.2.0/OptimalFeatureSelection/visualization/#Plotting-Grid-Search-Results-1>`.
 
         Compatibility
         -------------
@@ -701,18 +721,18 @@ class ROCCurve():
     """Container for ROC curve information.
 
     Julia Equivalent:
-    `IAI.ROCCurve <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.ROCCurve>`
+    `IAI.ROCCurve <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.ROCCurve>`
 
     Examples
     --------
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.2.0/IAI-Python/reference/#ROCCurve>`
     using trained `lnr` on the features `X` and labels `y`:
 
     >>> iai.ROCCurve(lnr, X, y)
 
     Construct an
-    `ROCCurve <https://docs.interpretable.ai/v2.1.0/IAI-Python/reference/#ROCCurve>`
+    `ROCCurve <https://docs.interpretable.ai/v2.2.0/IAI-Python/reference/#ROCCurve>`
     using predicted probabilities `probs` and true labels `y`, with
     probabilities indicating chance of predicting `positive_label`:
 
@@ -746,7 +766,7 @@ class ROCCurve():
         `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -763,7 +783,7 @@ class ROCCurve():
         """Visualize the ROC curve in the browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -780,7 +800,7 @@ class ROCCurve():
         - `auc`: the area-under-the-curve (AUC)
 
         Julia Equivalent:
-        `IAI.get_roc_curve_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_roc_curve_data>`
+        `IAI.get_roc_curve_data <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_roc_curve_data>`
 
         Examples
         --------
@@ -797,7 +817,7 @@ class ROCCurve():
         """Plot the ROC curve using `matplotlib`.
 
         Returns a
-        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.figure.Figure.html#matplotlib.figure.Figure>`
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/figure_api.html?highlight=figure#matplotlib.figure.Figure>`
         containing the ROC curve.
 
         In a Jupyter Notebook, the plot will be shown automatically. In a
@@ -833,7 +853,7 @@ class SurvivalCurve():
     time `t`.
 
     Julia Equivalent:
-    `IAI.SurvivalCurve <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.SurvivalCurve>`
+    `IAI.SurvivalCurve <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.SurvivalCurve>`
     """
     def __init__(self, jl_curve):
         self._jl_obj = jl_curve
@@ -852,7 +872,7 @@ class SurvivalCurve():
         - `'coefs'`: the probablility for each breakpoint on the curve
 
         Julia Equivalent:
-        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v2.1.0/IAIBase/reference/#IAI.get_survival_curve_data>`
+        `IAI.get_survival_curve_data <https://docs.interpretable.ai/v2.2.0/IAIBase/reference/#IAI.get_survival_curve_data>`
 
         Examples
         --------
