@@ -11,6 +11,7 @@ def iterate_samples(X):
     else:
         return X
 
+
 def get_sample_at_i(X, i):
     if isinstance(X, pd.DataFrame):
         return X.iloc[i, :]
@@ -19,6 +20,7 @@ def get_sample_at_i(X, i):
     else:
         return X[i]
 
+
 class Predictor():
     """An object that reads saved Interpretable AI models from JSON files and
     makes predictions.
@@ -46,13 +48,17 @@ class Predictor():
                 return v
             else:
                 return {
-                    'n' : len(v),
-                    'nzind' : [i + 1 for i, x in enumerate(v) if x != 0],
-                    'nzval' : [x for x in v if x != 0],
+                    'n': len(v),
+                    'nzind': [i + 1 for i, x in enumerate(v) if x != 0],
+                    'nzval': [x for x in v if x != 0],
                 }
 
         if self.model['_julia_type'] == 'OptimalFeatureSelectionClassifier':
-            fit = self.model['fit_']['inner']
+            fit = self.model['fit_']
+            if 'inner' in fit:
+                fit = fit['inner']
+            else:
+                fit = fit['logistic_fit']
             fit['beta'] = convert_sparse_vector(fit['beta'])
         elif self.model['_julia_type'] == 'OptimalFeatureSelectionRegressor':
             fit = self.model['fit_']
@@ -80,7 +86,7 @@ class Predictor():
                         t['beta'] = convert_sparse_vector(t['beta'])
 
     # Override autocompletion attributes to hide the internal functions
-    def __dir__(self): # pragma: no cover
+    def __dir__(self):  # pragma: no cover
         learner_type = self.model['_julia_type']
         if learner_type == 'OptimalTreeClassifier':
             return (
@@ -171,7 +177,7 @@ class Predictor():
             thresh = hyperplane_split['threshold']
             hyperval = self._get_hyperval(weights, x, features)
             return (hyperval < thresh)
-        raise Exception() # pragma: no cover
+        raise Exception()  # pragma: no cover
 
     def _apply_split_mixed(self, node, x):
         tree = self.model
@@ -253,7 +259,11 @@ class Predictor():
             # convert to probability matrix
             target = model['prb_']['data']['target']
             target_levels = target['classes']['levels']
-            fit = model['fit_']['inner']
+            fit = model['fit_']
+            if 'inner' in fit:
+                fit = fit['inner']
+            else:
+                fit = fit['logistic_fit']
             pred = self._decision_function(fit, x)
             p = 1 / (1 + np.exp(-pred))
             return {target_levels[0]: 1 - p,  target_levels[1]: p}
@@ -422,10 +432,12 @@ class Predictor():
         model = self.model
         learner_type = model['_julia_type']
 
+        fit = model['fit_']
         if learner_type == 'OptimalFeatureSelectionClassifier':
-            fit = model['fit_']['inner']
-        else:
-            fit = model['fit_']
+            if 'inner' in fit:
+                fit = fit['inner']
+            else:
+                fit = fit['logistic_fit']
 
         pred = self._decision_function(fit, x)
 
